@@ -48,7 +48,7 @@ class trinet:
     auth_body = {
         'grant_type': 'client_credentials'
     }
-    result = get(post_url, AUTH_HEADERS, params=auth_body)
+    result = get(post_url, headers=AUTH_HEADERS, params=auth_body)
     auth_result = result['content']
     self.access_token = auth_result['access_token']
     self.headers['Authorization'] = f"Bearer {self.access_token}"
@@ -56,112 +56,112 @@ class trinet:
 
   def list_all_employees(self, params=None):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/employees"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get employees. Result: {result}")
     return result
 
   def get_company_details(self, params=None):
     post_url = f"{BASE_URL}/v1/manage-company/{self.account_identifier}/org-details"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get company details. Result: {result}")
     return result
 
   def list_supervisors(self):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/supervisors"
-    result = get(post_url, self.headers)
+    result = get(post_url, headers=self.headers)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get supervisors. Result: {result}")
     return result
 
   def list_company_benefit_classes(self, params=None):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/benefit-classes"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get benefit-classes. Result: {result}")
     return result
 
   def list_company_benefits(self):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/benefits"
-    result = get(post_url, self.headers)
+    result = get(post_url, headers=self.headers)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get benefits. Result: {result}")
     return result
 
   def list_company_savings_plans(self):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/savings-plans"
-    result = get(post_url, self.headers)
+    result = get(post_url, headers=self.headers)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get savings-plans. Result: {result}")
     return result
 
   def list_company_changes(self, params=None):
     post_url = f"{BASE_URL}/v1/platform/company-changes"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get company-changes. Result: {result}")
     return result
 
   def list_employee_changes(self, params=None):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/employee-changes"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get employee-changes. Result: {result}")
     return result
 
   def list_departments(self, params=None):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/departments"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get departments. Result: {result}")
     return result
 
   def list_locations(self, params=None):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/locations"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get locations. Result: {result}")
     return result
 
   def list_job_codes(self, params=None):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/jobs"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get jobs. Result: {result}")
     return result
 
   def list_pay_codes(self, params=None):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/pay-codes"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get pay-codes. Result: {result}")
     return result
 
   def list_payroll_schedules(self, params=None):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/payroll-schedules"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get payroll-schedules. Result: {result}")
     return result
 
   def list_paygroups(self, params=None):
     post_url = f"{BASE_URL}/v1/company/{self.account_identifier}/paygroups"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get paygroups. Result: {result}")
     return result
 
   def get_employee_pay_info(self, employee_id, params=None):
     post_url = f"{BASE_URL}/v1/payroll/{self.account_identifier}/{employee_id}/pay-info"
-    result = get(post_url, self.headers, params=params)
+    result = get(post_url, headers=self.headers, params=params)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get pay-info for {employee_id}. Result: {result}")
     return result
 
   def get_employee_retirement_plan_elections(self, employee_id):
     post_url = f"{BASE_URL}/v1/retirement-plan/{self.account_identifier}/{employee_id}/contributions"
-    result = get(post_url, self.headers)
+    result = get(post_url, headers=self.headers)
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to get retirement plan elections for {employee_id}. Result: {result}")
     return result
