@@ -9,6 +9,9 @@ BASE_URL = 'https://books.zoho.com/api/v3/contacts'
 def create_contact(contact):
   authenticate()
   result = post(BASE_URL, HEADERS, json.dumps(contact))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = post(BASE_URL, HEADERS, json.dumps(contact))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to create contact. Result: {result}")
   return result
@@ -18,6 +21,9 @@ def update_contact(contact_id, contact):
   authenticate()
   post_url = f"{BASE_URL}/{contact_id}"
   result = put(post_url, HEADERS, json.dumps(contact))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = put(post_url, HEADERS, json.dumps(contact))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to update contact. Result: {result}")
   return result
@@ -27,6 +33,9 @@ def get_contact(contact_id):
   authenticate()
   post_url = f"{BASE_URL}/{contact_id}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve contact. Result: {result}")
   return result
@@ -68,6 +77,9 @@ def search_contacts(contact_name=None,
   for name, value in kwargs.items():
     post_url = f"{post_url}&{name}={value}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve contacts. Result: {result}")
   return result
